==> libjogl2-java_2.3.2+dfsg.orig.tar.xz: jogl-v2.3.2/src/jogl/classes/com/jogamp/opengl/util/stereo/LocationSensorParameter.java <==
/**
 * Copyright 2015 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list
 *       of conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY JogAmp Community ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JogAmp Community OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are those of the
 * authors and should not be interpreted as representing official policies, either expressed
 * or implied, of JogAmp Community.
 */
package com.jogamp.opengl.util.stereo;

import com.jogamp.opengl.math.geom.Frustum;

/**
 * Constant parameter of the positioning sensor to locate the {@link ViewerPose}.
 */
public final class LocationSensorParameter {
    /** The {@link Frustum} of the location sensor. */
    public final Frustum frustum;
    /** The {@link Frustum}'s {@link Frustum.FovDesc} description of the location sensor. */
    public final Frustum.FovDesc frustumDesc;
    /** The {@link Frustum}'s float[16] projection matrix of the location sensor. */
    public final float[] frustumProjMat;

    public LocationSensorParameter(final Frustum.FovDesc fovDesc) {
        this.frustumDesc = fovDesc;
        this.frustum = new Frustum();
        this.frustumProjMat = frustum.updateByFovDesc(new float[16], 0, true, fovDesc);
    }
    public final String toString() {
        return "LocationSensor["+frustumDesc+"]";
    }
}

==> libjogl2-java_2.6.0+dfsg.orig.tar.xz: jogl-v2.6.0/src/jogl/classes/com/jogamp/opengl/util/stereo/LocationSensorParameter.java <==
/**
 * Copyright 2015-2023 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list
 *       of conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY JogAmp Community ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JogAmp Community OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are those of the
 * authors and should not be interpreted as representing official policies, either expressed
 * or implied, of JogAmp Community.
 */
package com.jogamp.opengl.util.stereo;

import com.jogamp.math.Matrix4f;
import com.jogamp.math.geom.Frustum;

/**
 * Constant parameter of the positioning sensor to locate the {@link ViewerPose}.
 */
public final class LocationSensorParameter {
    /** The {@link Frustum} of the location sensor. */
    public final Frustum frustum;
    /** The {@link Frustum}'s {@link Frustum.FovDesc} description of the location sensor. */
    public final Frustum.FovDesc frustumDesc;
    /** The {@link Frustum}'s float[16] projection matrix of the location sensor. */
    public final Matrix4f frustumProjMat;

    public LocationSensorParameter(final Frustum.FovDesc fovDesc) {
        this.frustumDesc = fovDesc;
        this.frustum = new Frustum();
        this.frustumProjMat = frustum.updateByFovDesc(new Matrix4f(), fovDesc);
    }

    @Override
    public final String toString() {
        return "LocationSensor["+frustumDesc+"]";
    }
}
